import sys
# add the local lib folder as a search path
sys.path.insert(1, './lib')

import re 

certFile, certAlias = sys.argv[:2]

if not (len(sys.argv) == 2):
   sys.stderr.write("Invalid number of arguments, requires two arguments [certFile, certAlias]\n")   
   sys.exit(1)


def printMessage(message):    
    print "%s" % (message)

def saveAndSync():
    printMessage ("Saving and synchronizing changes.")
    AdminConfig.save()    
    printMessage("Saved the configuration changes.")    
    nodes=AdminControl.invoke(AdminControl.queryNames("type=DeploymentManager,*"), "syncActiveNodes", "true")
    printMessage ("Synchronized the following nodes: " + str(nodes))

def addSignerCertificate(certFile, certAlias):    

    # Get the current cell name
    cellName = AdminControl.getCell()
    
    # Search for previous certificates with the same alias
    certificates = AdminTask.listSignerCertificates('[-keyStoreName CellDefaultTrustStore -keyStoreScope (cell):' + cellName + ' ]').splitlines() 
    
    for certificate in certificates: 
        certificate = re.sub('^\[\[','[',certificate) 
        certificate = re.sub('\]\]$',']',certificate) 
        
        details = re.findall(r'\[([^]]*)\]',certificate) 
        
        for detail in details: 
            if ( detail == 'alias ' + certAlias + '' ): 
                printMessage( 'A previous certificate with an alias of ' + certAlias + ' was found, removing before importing ' + certFile )
                result = AdminTask.deleteSignerCertificate('[-keyStoreName CellDefaultTrustStore -keyStoreScope (cell):' + cellName + ' -certificateAlias ' + certAlias + ' ]') 

    # Import the signer certificate
    AdminTask.addSignerCertificate('[-keyStoreName CellDefaultTrustStore -keyStoreScope (cell):' + cellName + ' -certificateFilePath ' + certFile + ' -base64Encoded true -certificateAlias ' + certAlias + ' ]')
    
    printMessage('Successfully imported the CA Root certificate ' + certFile + ' from ' + certAlias + '.') 
    
    # Save and synchronize the changes to all nodes
    saveAndSync()

    return 0

addSignerCertificate(certFile, certAlias)